OC.L10N.register(
    "logreader",
    {
    "Logging" : "Logovanie",
    "Log Reader" : "Čítačka logov",
    "A log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
    "Log reader for Nextcloud" : "Čítačka logov pre Nextcloud",
    "Error parsing log" : "Chyba pri analýze logov",
    "Caused by " : "Spôsobené",
    "Debug" : "Ladenie",
    "Info" : "Info",
    "Warning" : "Varovanie",
    "Error" : "Chyba",
    "Fatal" : "Fatálne",
    "Copy" : "Kopírovať",
    "Copy raw" : "Kopírovať bez formátovania",
    "Copy formatted" : "Kopírovať formátované",
    "No server logs" : "Žiadne serverové logy",
    "One or more entries are hidden by the log level filter" : "Jeden alebo viac záznamov je skrytých filtrom úrovne logovania",
    "Everything is working fine" : "Všetko funguje dobre",
    "Level" : "Úroveň",
    "App" : "Aplikácia",
    "Message" : "Správa",
    "Time" : "Čas",
    "Load log file" : "Načítanie log súboru",
    "Invalid log file" : "Neplatný log súbor",
    "Log levels" : "Úroveň logov",
    "Log content" : "Obsah logov",
    "Live update" : "Živá aktualizácia",
    "Download logs" : "Prevziať logy"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
